@@ -49,6 +49,7 @@
 #include <QDesktopServices>
 #include <QFile>
 #include <QGuiApplication>
+#include <QJSEngine>
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
@@ -85,6 +86,7 @@ ApplicationController *ApplicationController::s_instance = nullptr;
 ApplicationController::ApplicationController(QObject *parent)
     : QObject(parent)
 {
+    Q_ASSERT(!s_instance);
     s_instance = this;
 }
 
@@ -93,6 +95,12 @@ ApplicationController::~ApplicationController()
     s_instance = nullptr;
 }
 
+ApplicationController *ApplicationControllerForeign::create(QQmlEngine*, QJSEngine*)
+{
+    QJSEngine::setObjectOwnership(ApplicationController::instance(), QJSEngine::CppOwnership);
+    return ApplicationController::instance();
+}
+
 void ApplicationController::setNetworkAccessManagerFactory(const std::function<QNetworkAccessManager *()> &namFactory)
 {
     m_namFactory = namFactory;
@@ -348,6 +356,8 @@ void ApplicationController::exportToFile(const QUrl &url)
     exporter.exportPasses(m_passMgr);
     exporter.exportHealthCertificates(healthCertificateManager());
     exporter.exportLiveData();
+    exporter.exportLocationSearchHistory();
+    exporter.exportPublicTransportAssets();
     exporter.exportSettings();
     Q_EMIT infoMessage(i18n("Export completed."));
 }
@@ -634,11 +644,11 @@ bool ApplicationController::importBundle(KItinerary::File *file)
 {
     Importer importer(file);
     if (importer.formatVersion() > BUNDLE_FORMAT_VERSION) {
-        Q_EMIT infoMessage(i18n("File was imported with a newer version of Itinerary. Some information might not be imported correctly."));
+        Q_EMIT infoMessage(i18n("File was exported with a newer version of Itinerary. Some information might not be imported correctly."));
     }
 
-    int count = 0;
-    int settingsCount = 0;
+    qsizetype count = 0;
+    qsizetype settingsCount = 0;
     {
         TripGroupingBlocker groupingBlocker(m_tripGroupMgr);
         QSignalBlocker blocker(this); // suppress infoMessage()
@@ -651,6 +661,8 @@ bool ApplicationController::importBundle(KItinerary::File *file)
         count += importer.importPasses(m_passMgr);
         count += importer.importHealthCertificates(healthCertificateManager());
         count += importer.importLiveData(m_liveDataMgr);
+        count += importer.importLocationSearchHistory();
+        count += importer.importPublicTransportAssets();
         settingsCount += importer.importSettings();
     }
 
@@ -675,7 +687,10 @@ void ApplicationController::pkPassUpdated(const QString &passId)
     const auto pass = m_pkPassMgr->pass(passId);
     KItinerary::ExtractorEngine engine;
     engine.setContent(QVariant::fromValue<KPkPass::Pass *>(pass), u"application/vnd.apple.pkpass");
-    m_resMgr->addReservationsWithPostProcessing(JsonLdDocument::fromJson(engine.extract()));
+    const auto ids = m_resMgr->addReservationsWithPostProcessing(JsonLdDocument::fromJson(engine.extract()));
+    if (ids.isEmpty()) {
+        m_passMgr->pkPassUpdated(passId, pass);
+    }
 }
 
 QString ApplicationController::addDocumentFromFile(const QUrl &url)
