@@ -9,13 +9,16 @@
 
 #include "transfer.h"
 
+#include <QChronoTimer>
 #include <QObject>
-#include <QTimer>
+#include <qqmlregistration.h>
 
 /** Transfer delegate logic. */
 class TransferDelegateController : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+
     Q_PROPERTY(Transfer transfer READ transfer WRITE setTransfer NOTIFY transferChanged)
     Q_PROPERTY(bool isCurrent READ isCurrent NOTIFY updated)
     Q_PROPERTY(float progress READ progress NOTIFY updated)
@@ -24,11 +27,11 @@ public:
     explicit TransferDelegateController(QObject *parent = nullptr);
     ~TransferDelegateController();
 
-    Transfer transfer() const;
+    [[nodiscard]] Transfer transfer() const;
     void setTransfer(const Transfer &transfer);
 
-    bool isCurrent() const;
-    float progress() const;
+    [[nodiscard]] bool isCurrent() const;
+    [[nodiscard]] float progress() const;
 
 Q_SIGNALS:
     void transferChanged();
@@ -38,7 +41,7 @@ private:
     void scheduleTimer();
 
     Transfer m_transfer;
-    QTimer m_updateTrigger;
+    QChronoTimer m_updateTrigger;
 };
 
 #endif // TRANSFERDELEGATECONTROLLER_H
