@@ -341,6 +341,13 @@ void TripGroupManager::transferChanged(const QString &resId, Transfer::Alignment
     }
 }
 
+bool TripGroupManager::hasUngroupedReservations() const
+{
+    return std::ranges::any_of(m_reservations, [this](const auto &batchId) {
+        return !m_reservationToGroupMap.contains(batchId);
+    });
+}
+
 void TripGroupManager::scanAll()
 {
     if (m_suspended) {
@@ -348,6 +355,10 @@ void TripGroupManager::scanAll()
         return;
     }
 
+    if (!hasUngroupedReservations()) {
+        return;
+    }
+
     qCDebug(Log);
     QString prevGroup;
     for (auto it = m_reservations.begin(); it != m_reservations.end(); ++it) {
@@ -357,12 +368,6 @@ void TripGroupManager::scanAll()
             continue;
         }
 
-        if (groupIt == m_reservationToGroupMap.constEnd()) {
-            prevGroup.clear();
-        } else {
-            prevGroup = groupIt.value();
-        }
-
         scanOne(it);
         prevGroup = m_reservationToGroupMap.value(*it);
     }
@@ -436,7 +441,7 @@ void TripGroupManager::scanOne(std::vector<QString>::const_iterator beginIt)
         }
 
         // maximum trip duration exceeded?
-        const auto endDt = SortUtil::endDateTime(curRes);
+        const auto endDt = SortUtil::hasEndTime(curRes) ? SortUtil::endDateTime(curRes) : SortUtil::startDateTime(curRes);
         if (explicitSearchDone && beginDt.daysTo(endDt) > MaximumTripDuration) {
             qDebug() << "  aborting search, maximum trip duration reached";
             break;
